@@ -24,6 +24,7 @@
 
 #include <KDebug>
 
+#include <KIO/Scheduler>
 #include <KShell>
 #include <KIO/Job>
 
@@ -759,7 +760,7 @@ void Data_Provider::startDownloadData()
 		connect( jobc, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( jobc, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[0] = jobc;
-		jobc->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)jobc );
 	}
 
 	if ( url1_prefix_xml != "" )
@@ -769,7 +770,7 @@ void Data_Provider::startDownloadData()
 		connect( job1, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job1, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[1] = job1;
-		job1->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job1 );
 	}
 
 	if ( url2_prefix_xml != "" )
@@ -779,7 +780,7 @@ void Data_Provider::startDownloadData()
 		connect( job2, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job2, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[2] = job2;
-		job2->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job2 );
 	}
 
 	if ( url3_prefix_xml != "" )
@@ -789,7 +790,7 @@ void Data_Provider::startDownloadData()
 		connect( job3, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job3, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[3] = job3;
-		job3->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job3 );
 	}
 
 	if ( url4_prefix_xml != "" )
@@ -799,7 +800,7 @@ void Data_Provider::startDownloadData()
 		connect( job4, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job4, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[4] = job4;
-		job4->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job4 );
 	}
 
 	if ( url5_prefix_xml != "" )
@@ -809,7 +810,7 @@ void Data_Provider::startDownloadData()
 		connect( job5, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job5, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[5] = job5;
-		job5->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job5 );
 	}
 
 	if ( url6_prefix_xml != "" )
@@ -819,7 +820,7 @@ void Data_Provider::startDownloadData()
 		connect( job6, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job6, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[6] = job6;
-		job6->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job6 );
 	}
 
 	if ( url7_prefix_xml != "" )
@@ -829,7 +830,7 @@ void Data_Provider::startDownloadData()
 		connect( job7, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( dataDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job7, SIGNAL( result( KJob * ) ), this, SLOT( dataDownloadFinished( KJob * ) ) );
 		data_job_list[7] = job7;
-		job7->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job7 );
 	}
 }
 
@@ -875,7 +876,7 @@ void Data_Provider::parseData()
 					connect( jobc, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( jobc, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[0] = jobc;
-					jobc->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)jobc );
 				}
 
 				if ( url1_follow_xml != "" )
@@ -886,7 +887,7 @@ void Data_Provider::parseData()
 					connect( job1, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job1, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[1] = job1;
-					job1->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job1 );
 				}
 
 				if ( url2_follow_xml != "" )
@@ -897,7 +898,7 @@ void Data_Provider::parseData()
 					connect( job2, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job2, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[2] = job2;
-					job2->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job2 );
 				}
 
 				if ( url3_follow_xml != "" )
@@ -908,7 +909,7 @@ void Data_Provider::parseData()
 					connect( job3, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job3, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[3] = job3;
-					job3->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job3 );
 				}
 
 				if ( url4_follow_xml != "" )
@@ -919,7 +920,7 @@ void Data_Provider::parseData()
 					connect( job4, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job4, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[4] = job4;
-					job4->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job4 );
 				}
 
 				if ( url5_follow_xml != "" )
@@ -930,7 +931,7 @@ void Data_Provider::parseData()
 					connect( job5, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job5, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[5] = job5;
-					job5->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job5 );
 				}
 
 				if ( url6_follow_xml != "" )
@@ -941,7 +942,7 @@ void Data_Provider::parseData()
 					connect( job6, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job6, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[6] = job6;
-					job6->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job6 );
 				}
 
 				if ( url7_follow_xml != "" )
@@ -952,7 +953,7 @@ void Data_Provider::parseData()
 					connect( job7, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( urlFollowDownloadedData( KIO::Job *, const QByteArray & ) ) );
 					connect( job7, SIGNAL( result( KJob * ) ), this, SLOT( urlFollowDownloadFinished( KJob * ) ) );
 					url_follow_job_list[7] = job7;
-					job7->start();
+					KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job7 );
 				}
 
 				return;
@@ -1056,7 +1057,7 @@ void Data_Provider::parseData()
 				connect( job_image, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( imageDownloadedData( KIO::Job *, const QByteArray & ) ) );
 				connect( job_image, SIGNAL( result( KJob * ) ), this, SLOT( imageDownloadFinished( KJob * ) ) );
 				image_job_list[i] = job_image;
-				job_image->start();
+				KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job_image );
 			}
 		}
 		if ( !job_started )
@@ -1104,6 +1105,7 @@ void Data_Provider::parseData()
 	data_current_wind = dataFromIdentifier( 9 );
 	qDebug() << "data_current_wind: " << data_current_wind;
 
+	qDebug() << "data_current_icon_code (orig): " << dataFromIdentifier( 10 );
 	data_current_icon_code = dataFromIdentifier( 10 ).toInt();
 	for ( j=0; j<WEATHER_CODE_TRANSFORM_SIZE; j++ )
 	{
@@ -1133,9 +1135,10 @@ void Data_Provider::parseData()
 		data_day_name[i] = dataFromIdentifier( 19 + i * 6 + 0 );
 		qDebug() << "data_day_name[" << i << "]: " << data_day_name[i];
 		data_day_temperature_high[i] = dataFromIdentifier( 19 + i * 6 + 1 );
-			qDebug() << "data_day_temperature_high[" << i << "]: " << data_day_temperature_high[i];
+		qDebug() << "data_day_temperature_high[" << i << "]: " << data_day_temperature_high[i];
 		data_day_temperature_low[i] = dataFromIdentifier( 19 + i * 6 + 2 );
-			qDebug() << "data_day_temperature_low[" << i << "]: " << data_day_temperature_low[i];
+		qDebug() << "data_day_temperature_low[" << i << "]: " << data_day_temperature_low[i];
+		qDebug() << "data_current_icon_code (orig): " << dataFromIdentifier( 19 + i * 6 + 3 );
 		data_day_icon_code[i] = dataFromIdentifier( 19 + i * 6 + 3 ).toInt();
 		for ( j=0; j<WEATHER_CODE_TRANSFORM_SIZE; j++ )
 		{
@@ -1156,7 +1159,7 @@ void Data_Provider::parseData()
 	connect( job_icon, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( iconDownloadedData( KIO::Job *, const QByteArray & ) ) );
 	connect( job_icon, SIGNAL( result( KJob * ) ), this, SLOT( iconDownloadFinished( KJob * ) ) );
 	icon_job_list[0] = job_icon;
-	job_icon->start();
+	KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job_icon );
 	for ( i=0; i<7; i++ )
 	{
 		icon_job_success_list[i+1] = false;
@@ -1164,7 +1167,7 @@ void Data_Provider::parseData()
 		connect( job_icon, SIGNAL( data( KIO::Job *, const QByteArray & ) ), this, SLOT( iconDownloadedData( KIO::Job *, const QByteArray & ) ) );
 		connect( job_icon, SIGNAL( result( KJob * ) ), this, SLOT( iconDownloadFinished( KJob * ) ) );
 		icon_job_list[i+1] = job_icon;
-		job_icon->start();
+		KIO::Scheduler::scheduleJob( (KIO::SimpleJob*)job_icon );
 	}
 
 	data_update_time = KGlobal::locale()->formatTime( QTime::currentTime(), false, false );
